%Random walk solver, Monte-Carlo
%V[k](s) = V[k](s) + alpha*(R[k] - V[k-1](s))
%len: length of the walk
%it: number of iterations
%A: initial V
%a: alpha value
%s0: starting step
function [V,RMSE]=rwMC(len,it,A,a,s0)

l = int32(len + 2);
if (mod(l,2) == 0)
    disp('length must be odd')
	return
end

%V: expected reward
if (nargin >= 3)
    [m,n]=size(A);
    if (m ~= 1 || n ~= len)
        disp('initial vector dimension mismatch')
        return
    end
    V = [0 A 1];
else
    V = ones(1,l) * 0.5;
end
RMSE = zeros(1,it);

%S: final result (to count RMS)
S = (1:len)/(len+1);

%iterations
for i=1:it
    %generate walk (starting from the middle)
    if (nargin > 4)
        t = s0;
    else
        t = idivide(l,2);
    end
    T = zeros(1,l);
    while (t ~= 1 && t ~= l)
        if (rand < 0.5)
            t = t - 1;
        else
            t = t + 1;
        end
        T(t) = 1; %points stepped on
    end
    
    %if the end reached set the reward for all the points stepped on
    R = zeros(1,l);
    if (t == l)
        R = T;
    end
    
    %iterative averaging
    if (nargin < 4)
        a = 1/i;
    end
    V = V + T .* (R - V) * a;
    Vr = V(1,2:l-1);
    RMSE(i) = sqrt(sum((Vr-S).*(Vr-S))/len);        
end
%remove the two ends
V=V(1,2:l-1);

