%plot Random walk results
%Random walk: In a sequence one can step forward or backward one step. The 
%V function (expected reward) will show what is the probability of reaching
%the rigth end of the path if starting from a given point.
%This function will compare and plot the result of a Monte-Carlo method and
%a Temporal-difference method for the problem.
function [M,T,Md,Td]=rwPlot(len,it,A,a,s0)
if (mod(int32(len),2) == 0)
    disp('length must be odd')
	return
end

switch nargin
    case 2
        [Em,Dm]=rwMC(len, it);
        [Et,Dt]=rwTD(len, it);
        sLm = sprintf('MC');
        sLt = sprintf('TD (alpha= 0.1)');
    case 3        
        [m,n]=size(A);
        if (m ~= 1 || n ~= len)
            disp('initial vector dimension mismatch')
            return
        end
        [Em,Dm]=rwMC(len, it,A);
        [Et,Dt]=rwTD(len, it,A);
        sLm = sprintf('MC');
        sLt = sprintf('TD (alpha= 0.1)');
    case 4        
        [m,n]=size(A);
        if (m ~= 1 || n ~= len)
            disp('initial vector dimension mismatch')
            return
        end
        [Em,Dm]=rwMC(len, it,A,a);
        [Et,Dt]=rwTD(len, it,A,a);
        sLm = sprintf('MC (alpha= %f)',a);
        sLt = sprintf('TD (alpha= %f)',a);
    case 5        
        [m,n]=size(A);
        if (m ~= 1 || n ~= len)
            disp('initial vector dimension mismatch')
            return
        end
        [Em,Dm]=rwMC(len, it,A,a,s0);
        [Et,Dt]=rwTD(len, it,A,a,s0);
        sLm = sprintf('MC (alpha= %f)',a);
        sLt = sprintf('TD (alpha= %f)',a);
end

sTitle = sprintf('MC & TD method comparison on Random walk (%d)',len);

figure(1);
plot(1:it, Dm,'b',1:it, Dt,'r');
xlabel('iteration');
ylabel('RMS');
legend(sLm,sLt);
title(sTitle);

figure(2);
plot(1:len, Em, '+b', 1:len, Et, '+r', 1:len, (1:len)/(len+1), 'k', ...
'LineWidth',2);
xlabel('state');
ylabel('value');
legend(sLm,sLt,'real values','Location','NorthWest');
title(sTitle);

M=Em;
T=Et;
Md = Dm(it);
Td = Dt(it);