%Random walk solver - Temporal-Difference
%V[k](s) = V[k-1](s) + alpha*(r + V[k-1](s) - V[k-1](s))
%len: length of the walk
%it: number of iterations
%A: initial V
%a: alpha value
%s0: starting step
function [V,RMSE]=rwTD(len,it,A,a,s0)
l = int32(len + 2);
if (mod(l,2) == 0)
    disp('length must be even')
	return
end

if (nargin < 4)
    a = 0.1;
end

if (nargin >= 3)
    [m,n]=size(A);
    if (m ~= 1 || n ~= len)
        disp('initial vector dimension mismatch')
        return
    end
    V = [0 A 0];
else
    V = ones(1,l) * 0.5;
    V(1) = 0;
    V(l) = 0;
end
R = zeros(1,l);
R(l) = 1;
RMSE = zeros(1,it);
S = (1:len)/(len+1);

%iterations
for i=1:it
    if (nargin > 4)
        s = s0;
    else
        s = idivide(l,2);
    end
    %Vp = V;
    while (s ~= 1 && s~= l)
        %store previous step
        sp = s;
        %generate step
        if (rand < 0.5)
            s = s - 1;
        else
            s = s + 1;
        end
        V(sp) = V(sp) + a*(R(s) + V(s) - V(sp));
    end
    Vr = V(1,2:l-1);
    RMSE(i) = sqrt(sum((Vr-S).*(Vr-S))/len);
end
%remove the two ends
V=V(1,2:l-1);